Commit f984d97b2208b48a6aec8877d0af357cca0c637d

Russell Belfer 2012-11-27T15:00:28

Clarify git_message_prettify comments

diff --git a/include/git2/message.h b/include/git2/message.h
index e20173f..e89d022 100644
--- a/include/git2/message.h
+++ b/include/git2/message.h
@@ -23,25 +23,27 @@ GIT_BEGIN_DECL
  *
  * Optionally, can remove lines starting with a "#".
  *
- * @param out The user-allocated buffer which will be filled with
- * the cleaned up message. Pass NULL if you just want to get the size of the
- * prettified message as the output value.
+ * @param out The user-allocated buffer which will be filled with the
+ *     cleaned up message. Pass NULL if you just want to get the needed
+ *     size of the prettified message as the output value.
  *
  * @param size The size of the allocated buffer message_out.
  *
  * @param message The message to be prettified.
  *
- * @param strip_comments 1 to remove lines starting with a "#", 0 otherwise.
+ * @param strip_comments Non-zero to remove lines starting with "#", 0 to
+ *     leave them in.
  *
  * @return -1 on error, else number of characters in prettified message
- * including the trailing NUL byte
+ *     including the trailing NUL byte
  */
 GIT_EXTERN(int) git_message_prettify(
 	char *out,
-	size_t buffer_size,
+	size_t out_size,
 	const char *message,
 	int strip_comments);
 
 /** @} */
 GIT_END_DECL
+
 #endif /* INCLUDE_git_message_h__ */
@@ -23,25 +23,27 @@ GIT_BEGIN_DECL
  *
- * @param size The size of the allocated buffer message_out.
+ * @param out_size Size of the `out` buffer in bytes.
  *
  * @param message The message to be prettified.